@@ -722,6 +722,28 @@ ID要强调当下分解的多样性？因为走势本身就是当下形成中的
 --摘自《2007-08-28 21:57 《论语》详解：给所有曲解孔子的人（68）》
 """,
 
+    "82": """
+何谓“察”？分辨、明察、知晓也。只有排除一切好恶，当下直观，才有真正的“察”。任何人都有其情
+绪、好恶，但这情绪、好恶就是“察”的最大干扰，“远虑”离不开“察”，而“察”就要摈弃一切好恶，当
+下直观，这样才有可能进而“远虑”。
+
+--摘自《2006-11-23 12:00 《论语》详解：给所有曲解孔子的人（34）》
+""",
+
+    "83": """
+“虑”，审察、思虑、谋划。“虑”，不是哈姆雷特式的，而是审察、思虑、谋划的统一，三者缺一不
+可，而最终必须落在行动上，没有行动的“虑”也不过是幻想而已。上面的所有工夫，都构成“习”的
+一环，但仍不是“习”的全部。“习”的关键在于对现实逻辑关系把握后的改变，是转现实而不是被现
+实所转，只有这样，才勉强算得上“远虑”。
+
+--摘自《2006-11-21 12:00 《论语》详解：给所有曲解孔子的人（33）》
+""",
+
+    "84": """
+一切都从也只能从现实出发，现实在什么阶段，什么位次，是必须首要分析的问题。
+
+--摘自《2006-11-10 12:00 《论语》详解：给所有曲解孔子的人（27）》
+""",
 }
 
 
