@@ -14,13 +14,13 @@ from tqdm import tqdm
 from deprecated import deprecated
 from datetime import datetime, timedelta
 from typing import Callable, List, AnyStr
+from sklearn.preprocessing import KBinsDiscretizer
 
 from .. import envs
 from ..traders.advanced import CzscAdvancedTrader, BarGenerator
 from ..traders.utils import freq_cn2ts
 from ..data.ts_cache import TsDataCache
 from ..objects import RawBar, Signal
-from ..signals.signals import get_default_signals
 from ..utils.cache import home_path
 
 
@@ -78,6 +78,29 @@ def analyze_signal_keys(dfs: pd.DataFrame, keys: List[str], mode: int = 0) -> pd
     return dfr
 
 
+def discretizer(df: pd.DataFrame, col: str, n_bins=20, encode='ordinal', strategy='quantile'):
+    """使用 KBinsDiscretizer 对连续变量在时间截面上进行离散化
+
+    :param df: 数据对象
+    :param col: 连续变量列名
+    :param n_bins: 参见 KBinsDiscretizer 文档
+    :param encode: 参见 KBinsDiscretizer 文档
+    :param strategy: 参见 KBinsDiscretizer 文档
+    :return:
+    """
+    assert col in df.columns, f'{col} not in {df.columns}'
+    assert 'dt' in df.columns
+
+    new_col = f'{col}_bins{n_bins}'
+    results = []
+    for dt, dfg in tqdm(df.groupby('dt')):
+        kb = KBinsDiscretizer(n_bins=n_bins, encode=encode, strategy=strategy)
+        dfg[new_col] = kb.fit_transform(dfg[col].values.reshape(-1, 1)).ravel()
+        results.append(dfg)
+    df = pd.concat(results, ignore_index=True)
+    return df
+
+
 def get_index_beta(dc: TsDataCache, sdt: str, edt: str, freq='D', file_xlsx=None, indices=None):
     """获取基准指数的Beta
 
@@ -176,7 +199,7 @@ def generate_signals(bars: List[RawBar],
 
 def check_signals_acc(bars: List[RawBar],
                       signals: List[Signal] = None,
-                      get_signals: Callable = get_default_signals) -> None:
+                      get_signals: Callable = None) -> None:
     """人工验证形态信号识别的准确性的辅助工具：
 
     输入基础周期K线和想要验证的信号，输出信号识别结果的快照
